UtilPrint class

UtilPrint 打印工具类

Constructors

UtilPrint()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

logger → Logger
日志打印器
final

Static Methods

error(dynamic message, Object? e, StackTrace stack, {DateTime? time}) → dynamic
错误
info(dynamic message, {DateTime? time, Object? error, StackTrace? stackTrace}) → dynamic
信息
trace(dynamic message, {DateTime? time, Object? error, StackTrace? stackTrace}) → dynamic
跟踪
warn(dynamic message, {DateTime? time, Object? error, StackTrace? stackTrace}) → dynamic
警告